@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright © 2001-2016 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2017 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ static QString xtermCommands[] = {
 = Class KAlarmPrefDlg
 =============================================================================*/
 
-KAlarmPrefDlg* KAlarmPrefDlg::mInstance = Q_NULLPTR;
+KAlarmPrefDlg* KAlarmPrefDlg::mInstance = nullptr;
 
 void KAlarmPrefDlg::display()
 {
@@ -200,7 +200,7 @@ KAlarmPrefDlg::KAlarmPrefDlg()
 
 KAlarmPrefDlg::~KAlarmPrefDlg()
 {
-    mInstance = Q_NULLPTR;
+    mInstance = nullptr;
 }
 
 void KAlarmPrefDlg::slotHelp()
@@ -1621,7 +1621,11 @@ QString EditPrefTab::validate()
 =============================================================================*/
 
 ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
-    : PrefsTabBase(scrollGroup)
+    : PrefsTabBase(scrollGroup),
+      mShowInSystemTrayCheck(nullptr),
+      mShowInSystemTrayGroup(nullptr),
+      mAutoHideSystemTray(nullptr),
+      mAutoHideSystemTrayPeriod(nullptr)
 {
     mTabs = new QTabWidget();
     topLayout()->addWidget(mTabs);
@@ -1638,57 +1642,76 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     topWindows->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTabWindows = mTabs->addTab(widget, i18nc("@title:tab", "Alarm Windows"));
 
-    // Run-in-system-tray group box
-    mShowInSystemTray = new QGroupBox(i18nc("@option:check", "Show in system tray"));
-    mShowInSystemTray->setCheckable(true);
-    mShowInSystemTray->setWhatsThis(
-          xi18nc("@info:whatsthis", "<para>Check to show <application>KAlarm</application>'s icon in the system tray."
-               " Showing it in the system tray provides easy access and a status indication.</para>"));
-    topGeneral->addWidget(mShowInSystemTray);
-    QGridLayout* grid = new QGridLayout(mShowInSystemTray);
-    grid->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
-    grid->setColumnStretch(1, 1);
-    grid->setColumnMinimumWidth(0, indentWidth());
+    // Run-in-system-tray check box or group.
+    static const QString showInSysTrayText = i18nc("@option:check", "Show in system tray");
+    static const QString showInSysTrayWhatsThis = xi18nc("@info:whatsthis",
+            "<para>Check to show <application>KAlarm</application>'s icon in the system tray."
+            " Showing it in the system tray provides easy access and a status indication.</para>");
+    if(Preferences::noAutoHideSystemTrayDesktops().contains(KAlarm::currentDesktopIdentityName()))
+    {
+        // Run-in-system-tray check box.
+        // This desktop type doesn't provide GUI controls to view hidden system tray
+        // icons, so don't show options to hide the system tray icon.
+        widget = new QWidget;  // this is to allow left adjustment
+        topGeneral->addWidget(widget);
+        QHBoxLayout* box = new QHBoxLayout(widget);
+        mShowInSystemTrayCheck = new QCheckBox(showInSysTrayText);
+        mShowInSystemTrayCheck->setWhatsThis(showInSysTrayWhatsThis);
+        box->addWidget(mShowInSystemTrayCheck);
+        box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
+    }
+    else
+    {
+        // Run-in-system-tray group box
+        mShowInSystemTrayGroup = new QGroupBox(showInSysTrayText);
+        mShowInSystemTrayGroup->setCheckable(true);
+        mShowInSystemTrayGroup->setWhatsThis(showInSysTrayWhatsThis);
+        topGeneral->addWidget(mShowInSystemTrayGroup);
+        QGridLayout* grid = new QGridLayout(mShowInSystemTrayGroup);
+        grid->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+        grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+        grid->setColumnStretch(1, 1);
+        grid->setColumnMinimumWidth(0, indentWidth());
 
-    mAutoHideSystemTray = new ButtonGroup(mShowInSystemTray);
-    connect(mAutoHideSystemTray, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotAutoHideSysTrayChanged);
+        mAutoHideSystemTray = new ButtonGroup(mShowInSystemTrayGroup);
+        connect(mAutoHideSystemTray, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotAutoHideSysTrayChanged);
 
-    QRadioButton* radio = new QRadioButton(i18nc("@option:radio Always show KAlarm icon", "Always show"), mShowInSystemTray);
-    mAutoHideSystemTray->addButton(radio, 0);
-    radio->setWhatsThis(
-          xi18nc("@info:whatsthis",
-                "Check to show <application>KAlarm</application>'s icon in the system tray "
-                "regardless of whether alarms are due."));
-    grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
+        QRadioButton* radio = new QRadioButton(i18nc("@option:radio Always show KAlarm icon", "Always show"), mShowInSystemTrayGroup);
+        mAutoHideSystemTray->addButton(radio, 0);
+        radio->setWhatsThis(
+              xi18nc("@info:whatsthis",
+                    "Check to show <application>KAlarm</application>'s icon in the system tray "
+                    "regardless of whether alarms are due."));
+        grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
 
-    radio = new QRadioButton(i18nc("@option:radio", "Automatically hide if no active alarms"), mShowInSystemTray);
-    mAutoHideSystemTray->addButton(radio, 1);
-    radio->setWhatsThis(
-          xi18nc("@info:whatsthis",
-                "Check to automatically hide <application>KAlarm</application>'s icon in "
-                "the system tray if there are no active alarms. When hidden, the icon can "
-                "always be made visible by use of the system tray option to show hidden icons."));
-    grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
+        radio = new QRadioButton(i18nc("@option:radio", "Automatically hide if no active alarms"), mShowInSystemTrayGroup);
+        mAutoHideSystemTray->addButton(radio, 1);
+        radio->setWhatsThis(
+              xi18nc("@info:whatsthis",
+                    "Check to automatically hide <application>KAlarm</application>'s icon in "
+                    "the system tray if there are no active alarms. When hidden, the icon can "
+                    "always be made visible by use of the system tray option to show hidden icons."));
+        grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
 
-    QString text = xi18nc("@info:whatsthis",
-                         "Check to automatically hide <application>KAlarm</application>'s icon in the "
-                         "system tray if no alarms are due within the specified time period. When hidden, "
-                         "the icon can always be made visible by use of the system tray option to show hidden icons.");
-    radio = new QRadioButton(i18nc("@option:radio", "Automatically hide if no alarm due within time period:"), mShowInSystemTray);
-    radio->setWhatsThis(text);
-    mAutoHideSystemTray->addButton(radio, 2);
-    grid->addWidget(radio, 2, 0, 1, 2, Qt::AlignLeft);
-    mAutoHideSystemTrayPeriod = new TimePeriod(true, mShowInSystemTray);
-    mAutoHideSystemTrayPeriod->setWhatsThis(text);
-    mAutoHideSystemTrayPeriod->setMaximumWidth(mAutoHideSystemTrayPeriod->sizeHint().width());
-    grid->addWidget(mAutoHideSystemTrayPeriod, 3, 1, 1, 1, Qt::AlignLeft);
-    mShowInSystemTray->setMaximumHeight(mShowInSystemTray->sizeHint().height());
+        QString text = xi18nc("@info:whatsthis",
+                             "Check to automatically hide <application>KAlarm</application>'s icon in the "
+                             "system tray if no alarms are due within the specified time period. When hidden, "
+                             "the icon can always be made visible by use of the system tray option to show hidden icons.");
+        radio = new QRadioButton(i18nc("@option:radio", "Automatically hide if no alarm due within time period:"), mShowInSystemTrayGroup);
+        radio->setWhatsThis(text);
+        mAutoHideSystemTray->addButton(radio, 2);
+        grid->addWidget(radio, 2, 0, 1, 2, Qt::AlignLeft);
+        mAutoHideSystemTrayPeriod = new TimePeriod(true, mShowInSystemTrayGroup);
+        mAutoHideSystemTrayPeriod->setWhatsThis(text);
+        mAutoHideSystemTrayPeriod->setMaximumWidth(mAutoHideSystemTrayPeriod->sizeHint().width());
+        grid->addWidget(mAutoHideSystemTrayPeriod, 3, 1, 1, 1, Qt::AlignLeft);
+        mShowInSystemTrayGroup->setMaximumHeight(mShowInSystemTrayGroup->sizeHint().height());
+    }
 
     // System tray tooltip group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "System Tray Tooltip"));
     topGeneral->addWidget(group);
-    grid = new QGridLayout(group);
+    QGridLayout* grid = new QGridLayout(group);
     grid->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
     grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->setColumnStretch(2, 1);
@@ -1797,7 +1820,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
           "<para>Choose how to reduce the chance of alarm messages being accidentally acknowledged:"
           "<list><item>Position alarm message windows as far as possible from the current mouse cursor location, or</item>"
           "<item>Position alarm message windows in the center of the screen, but disable buttons for a short time after the window is displayed.</item></list></para>");
-    radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
+    QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
     mWindowPosition->addButton(radio, 0);
     radio->setWhatsThis(whatsthis);
     grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
@@ -1840,7 +1863,10 @@ void ViewPrefTab::restore(bool, bool allTabs)
 {
     if (allTabs  ||  mTabs->currentIndex() == mTabGeneral)
     {
-        mShowInSystemTray->setChecked(Preferences::showInSystemTray());
+        if (mShowInSystemTrayGroup)
+            mShowInSystemTrayGroup->setChecked(Preferences::showInSystemTray());
+        else
+            mShowInSystemTrayCheck->setChecked(Preferences::showInSystemTray());
         int id;
         int mins = Preferences::autoHideSystemTray();
         switch (mins)
@@ -1863,7 +1889,8 @@ void ViewPrefTab::restore(bool, bool allTabs)
                 break;
             }
         }
-        mAutoHideSystemTray->setButton(id);
+        if (mAutoHideSystemTray)
+            mAutoHideSystemTray->setButton(id);
         setTooltip(Preferences::tooltipAlarmCount(),
                    Preferences::showTooltipAlarmTime(),
                    Preferences::showTooltipTimeToAlarm(),
@@ -1901,10 +1928,10 @@ void ViewPrefTab::apply(bool syncToDisc)
     QString text = mTooltipTimeToPrefix->text();
     if (text != Preferences::tooltipTimeToPrefix())
         Preferences::setTooltipTimeToPrefix(text);
-    b = mShowInSystemTray->isChecked();
+    b = mShowInSystemTrayGroup ? mShowInSystemTrayGroup->isChecked() : mShowInSystemTrayCheck->isChecked();
     if (b != Preferences::showInSystemTray())
         Preferences::setShowInSystemTray(b);
-    if (b)
+    if (b  &&  mAutoHideSystemTray)
     {
         switch (mAutoHideSystemTray->selectedId())
         {
@@ -1988,7 +2015,8 @@ void ViewPrefTab::slotTooltipTimeToToggled(bool on)
 
 void ViewPrefTab::slotAutoHideSysTrayChanged(QAbstractButton* button)
 {
-    mAutoHideSystemTrayPeriod->setEnabled(mAutoHideSystemTray->id(button) == 2);
+    if (mAutoHideSystemTray)
+        mAutoHideSystemTrayPeriod->setEnabled(mAutoHideSystemTray->id(button) == 2);
 }
 
 void ViewPrefTab::slotWindowPosChanged(QAbstractButton* button)
